AppLocalizationsZh class
The translations for Chinese (zh).
- Inheritance
-
- Object
- AppLocalizations
- AppLocalizationsZh
Constructors
- AppLocalizationsZh([String locale = 'zh'])
Properties
- camera → String
-
No description provided for @camera.
no setteroverride
- gallery → String
-
No description provided for @gallery.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- invalidImageFormat → String
-
No description provided for @invalidImageFormat.
no setteroverride
- localeName → String
-
finalinherited
- noData → String
-
No description provided for @noData.
no setteroverride
- none → String
-
No description provided for @none.
no setteroverride
- pleaseEnter → String
-
No description provided for @pleaseEnter.
no setteroverride
- pleaseSelect → String
-
No description provided for @pleaseSelect.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
unsupportedImagesSkipped(
int count) → String -
Shown when some selected images are not supported.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited